# Generated by Django 4.1.3 on 2023-01-05 11:37

from django.db import migrations, models
from django.template.defaultfilters import slugify

def slugifyNullObjects(model, db_alias):
    for obj in model.objects.using(db_alias).filter(slug__isnull=True):
        slug = slugify(obj.title)
        obj.slug = slug

        # Check if another object already has that slug, and if so add a suffix (starting from 2: e.g. my-slug-2)
        suffix = 2
        while model.objects.using(db_alias).filter(slug=obj.slug).exists():
            obj.slug = f"{slug}-{suffix}"
            suffix = suffix + 1
        obj.save()

class Migration(migrations.Migration):

    dependencies = [
        ("openbook_terms", "0002_topic_is_discover_spaces_default"),
    ]


    def forwards_func(apps, schema_editor):
        SkillModel = apps.get_model("openbook_terms.Skill")
        TopicModel = apps.get_model("openbook_terms.Topic")
        SDGModel = apps.get_model("openbook_terms.SDG")
        db_alias = schema_editor.connection.alias
        slugifyNullObjects(SkillModel, db_alias)
        slugifyNullObjects(TopicModel, db_alias)
        slugifyNullObjects(SDGModel, db_alias)

    operations = [
        migrations.AddField(
            model_name="sdg",
            name="slug",
            field=models.SlugField(max_length=128, null=True, unique=True, verbose_name="slug"),
        ),
        migrations.AddField(
            model_name="skill",
            name="slug",
            field=models.SlugField(max_length=128, null=True, unique=True, verbose_name="slug"),
        ),
        migrations.AddField(
            model_name="topic",
            name="slug",
            field=models.SlugField(max_length=128, null=True, unique=True, verbose_name="slug"),
        ),
        migrations.RunPython(forwards_func,),
    ]
